"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultSize = exports.stylingSettings = exports.checkboxStates = void 0;
const react_native_1 = require("react-native");
const framework_1 = require("@fluentui-react-native/framework");
const styling_utils_1 = require("@fluentui-react-native/styling-utils");
const tokens_1 = require("@fluentui-react-native/tokens");
const Checkbox_types_1 = require("./Checkbox.types");
const CheckboxTokens_1 = require("./CheckboxTokens");
exports.checkboxStates = [
    'medium',
    'large',
    'circular',
    'label',
    'labelIsBefore',
    'hovered',
    'focused',
    'pressed',
    'checked',
    'disabled',
];
const hasPresetRententionForA11y = react_native_1.Platform.OS === 'android';
exports.stylingSettings = {
    tokens: [CheckboxTokens_1.defaultCheckboxTokens, Checkbox_types_1.checkboxName],
    states: exports.checkboxStates,
    slotProps: {
        root: (0, framework_1.buildProps)((tokens, theme) => ({
            style: {
                display: 'flex',
                alignItems: 'center',
                flexDirection: 'row',
                alignSelf: 'flex-start',
                backgroundColor: tokens.backgroundColor,
                padding: tokens.padding,
                paddingHorizontal: tokens.paddingHorizontal,
                ...tokens_1.borderStyles.from(tokens, theme),
            },
            android_ripple: { color: tokens.rippleColor, foreground: true },
        }), ['backgroundColor', 'padding', ...tokens_1.borderStyles.keys, 'rippleColor']),
        label: (0, framework_1.buildProps)((tokens, theme) => ({
            style: contentStyling(tokens, theme),
        }), ['spacingLabelAfter', 'spacingLabelBefore', 'color', ...tokens_1.fontStyles.keys]),
        checkbox: (0, framework_1.buildProps)((tokens) => ({
            style: {
                height: tokens.checkboxSize,
                width: tokens.checkboxSize,
                backgroundColor: tokens.checkboxBackgroundColor,
                borderColor: tokens.checkboxBorderColor,
                borderRadius: tokens.checkboxBorderRadius,
                borderWidth: tokens.checkboxBorderWidth,
                alignItems: 'center',
                justifyContent: 'center',
            },
            ...(hasPresetRententionForA11y && {
                pressRetentionOffset: typeof tokens.padding === 'number' ? tokens.padding : typeof tokens.padding === 'string' ? parseFloat(tokens.padding) : 0, /// Retention of the press area outside of the checkbox equal to padding to match accessibility requirement
            }),
            android_ripple: { color: tokens.rippleColor, radius: tokens.checkmarkSize, foreground: true },
        }), ['checkboxBackgroundColor', 'checkboxBorderColor', 'checkboxBorderRadius', 'checkboxBorderWidth', 'checkboxSize', 'rippleColor']),
        checkmark: (0, framework_1.buildProps)((tokens) => ({
            style: {
                width: tokens.checkmarkSize,
                height: tokens.checkmarkSize,
                color: tokens.checkmarkColor,
                opacity: tokens.checkmarkOpacity,
            },
        }), ['checkmarkColor', 'checkmarkSize', 'checkmarkOpacity']),
        required: (0, framework_1.buildProps)((tokens, theme) => ({
            style: { color: tokens.requiredColor, paddingStart: tokens.requiredPadding, ...tokens_1.fontStyles.from(tokens, theme) },
        }), ['requiredColor', 'requiredPadding', ...tokens_1.fontStyles.keys]),
    },
};
const getDefaultSize = () => {
    return 'medium';
};
exports.getDefaultSize = getDefaultSize;
const contentStyling = (tokens, theme) => {
    const textAdjustment = (0, styling_utils_1.getTextMarginAdjustment)();
    const spacingLabelAfter = tokens.spacingLabelAfter
        ? {
            marginStart: textAdjustment.marginStart + tokens.spacingLabelAfter,
        }
        : {};
    const spacingLabelBefore = tokens.spacingLabelBefore
        ? {
            marginEnd: textAdjustment.marginEnd + tokens.spacingLabelBefore,
        }
        : {};
    return {
        color: tokens.color,
        ...spacingLabelBefore,
        ...spacingLabelAfter,
        ...tokens_1.fontStyles.from(tokens, theme),
    };
};
//# sourceMappingURL=Checkbox.styling.js.map