"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCheckbox = void 0;
const React = __importStar(require("react"));
const framework_1 = require("@fluentui-react-native/framework");
const interactive_hooks_1 = require("@fluentui-react-native/interactive-hooks");
const defaultAccessibilityActions = [{ name: 'Toggle' }];
/**
 * Re-usable hook for FURN Checkbox.
 * This hook configures checkbox props and state for FURN Checkbox.
 *
 * @param props user props sent to FURN Checkbox
 * @returns configured props and state for FURN Checkbox
 */
const useCheckbox = (props) => {
    const defaultComponentRef = React.useRef(null);
    const { accessible, accessibilityActions, accessibilityLabel, accessibilityRole, accessibilityState, componentRef = defaultComponentRef, checked, defaultChecked, enableFocusRing, focusable, labelPosition, label, onAccessibilityAction, onChange, required, ...rest } = props;
    // Warns defaultChecked and checked being mutually exclusive.
    if (defaultChecked != undefined && checked != undefined) {
        console.warn('defaultChecked and checked are mutually exclusive to one another. Use one or the other.');
    }
    // Re-usable hook for toggle components.
    const [isChecked, toggleChecked] = (0, interactive_hooks_1.useAsToggleWithEvent)(defaultChecked, checked, onChange);
    // Ensure focus is placed on checkbox after click
    const toggleCheckedWithFocus = (0, interactive_hooks_1.useOnPressWithFocus)(componentRef, toggleChecked);
    // attach the pressable state handlers
    const pressable = (0, interactive_hooks_1.usePressableState)({ onPress: toggleCheckedWithFocus, ...rest });
    const buttonRef = (0, interactive_hooks_1.useViewCommandFocus)(componentRef);
    // Handles the "Space" key toggling the Checkbox
    const onKeyUpProps = (0, interactive_hooks_1.useKeyProps)(toggleChecked, ' ');
    const accessibilityActionsProp = accessibilityActions
        ? [...defaultAccessibilityActions, ...accessibilityActions]
        : defaultAccessibilityActions;
    const state = {
        ...pressable.state,
        disabled: !!props.disabled,
        checked: isChecked,
        labelIsBefore: labelPosition === 'before' ? true : false,
    };
    const onAccessibilityActionProp = React.useCallback((event) => {
        switch (event.nativeEvent.actionName) {
            case 'Toggle':
                toggleChecked(event);
                break;
        }
        onAccessibilityAction && onAccessibilityAction(event);
    }, [toggleChecked, onAccessibilityAction]);
    return {
        props: {
            ref: buttonRef,
            ...pressable.props,
            accessible: accessible ?? true,
            accessibilityRole: accessibilityRole ?? 'checkbox',
            accessibilityLabel: accessibilityLabel ?? label,
            accessibilityState: getAccessibilityState(state.disabled, state.checked, !!required, accessibilityState),
            accessibilityActions: accessibilityActionsProp,
            focusable: focusable ?? !state.disabled,
            onAccessibilityAction: onAccessibilityActionProp,
            enableFocusRing: enableFocusRing ?? true,
            ...onKeyUpProps,
            ...props,
        },
        state: {
            ...pressable.state,
            ...state,
        },
    };
};
exports.useCheckbox = useCheckbox;
const getAccessibilityState = (0, framework_1.memoize)(getAccessibilityStateWorker);
function getAccessibilityStateWorker(disabled, checked, required, accessibilityState) {
    checked = checked ?? false; // Make the value of checked as false when checked is undefined or null for screen reader to announce 'unchecked'
    if (accessibilityState) {
        return { disabled, checked, required, ...accessibilityState };
    }
    return { disabled, checked, required };
}
//# sourceMappingURL=useCheckbox.js.map