import { Platform } from 'react-native';
import { buildProps } from '@fluentui-react-native/framework';
import { getTextMarginAdjustment } from '@fluentui-react-native/styling-utils';
import { borderStyles, fontStyles } from '@fluentui-react-native/tokens';
import { checkboxName } from './Checkbox.types';
import { defaultCheckboxTokens } from './CheckboxTokens';
export const checkboxStates = [
    'medium',
    'large',
    'circular',
    'label',
    'labelIsBefore',
    'hovered',
    'focused',
    'pressed',
    'checked',
    'disabled',
];
const hasPresetRententionForA11y = Platform.OS === 'android';
export const stylingSettings = {
    tokens: [defaultCheckboxTokens, checkboxName],
    states: checkboxStates,
    slotProps: {
        root: buildProps((tokens, theme) => ({
            style: {
                display: 'flex',
                alignItems: 'center',
                flexDirection: 'row',
                alignSelf: 'flex-start',
                backgroundColor: tokens.backgroundColor,
                padding: tokens.padding,
                paddingHorizontal: tokens.paddingHorizontal,
                ...borderStyles.from(tokens, theme),
            },
            android_ripple: { color: tokens.rippleColor, foreground: true },
        }), ['backgroundColor', 'padding', ...borderStyles.keys, 'rippleColor']),
        label: buildProps((tokens, theme) => ({
            style: contentStyling(tokens, theme),
        }), ['spacingLabelAfter', 'spacingLabelBefore', 'color', ...fontStyles.keys]),
        checkbox: buildProps((tokens) => ({
            style: {
                height: tokens.checkboxSize,
                width: tokens.checkboxSize,
                backgroundColor: tokens.checkboxBackgroundColor,
                borderColor: tokens.checkboxBorderColor,
                borderRadius: tokens.checkboxBorderRadius,
                borderWidth: tokens.checkboxBorderWidth,
                alignItems: 'center',
                justifyContent: 'center',
            },
            ...(hasPresetRententionForA11y && {
                pressRetentionOffset: typeof tokens.padding === 'number' ? tokens.padding : typeof tokens.padding === 'string' ? parseFloat(tokens.padding) : 0, /// Retention of the press area outside of the checkbox equal to padding to match accessibility requirement
            }),
            android_ripple: { color: tokens.rippleColor, radius: tokens.checkmarkSize, foreground: true },
        }), ['checkboxBackgroundColor', 'checkboxBorderColor', 'checkboxBorderRadius', 'checkboxBorderWidth', 'checkboxSize', 'rippleColor']),
        checkmark: buildProps((tokens) => ({
            style: {
                width: tokens.checkmarkSize,
                height: tokens.checkmarkSize,
                color: tokens.checkmarkColor,
                opacity: tokens.checkmarkOpacity,
            },
        }), ['checkmarkColor', 'checkmarkSize', 'checkmarkOpacity']),
        required: buildProps((tokens, theme) => ({
            style: { color: tokens.requiredColor, paddingStart: tokens.requiredPadding, ...fontStyles.from(tokens, theme) },
        }), ['requiredColor', 'requiredPadding', ...fontStyles.keys]),
    },
};
export const getDefaultSize = () => {
    return 'medium';
};
const contentStyling = (tokens, theme) => {
    const textAdjustment = getTextMarginAdjustment();
    const spacingLabelAfter = tokens.spacingLabelAfter
        ? {
            marginStart: textAdjustment.marginStart + tokens.spacingLabelAfter,
        }
        : {};
    const spacingLabelBefore = tokens.spacingLabelBefore
        ? {
            marginEnd: textAdjustment.marginEnd + tokens.spacingLabelBefore,
        }
        : {};
    return {
        color: tokens.color,
        ...spacingLabelBefore,
        ...spacingLabelAfter,
        ...fontStyles.from(tokens, theme),
    };
};
//# sourceMappingURL=Checkbox.styling.js.map